@@ -1,4 +1,5 @@
 from abc import abstractmethod
+from .registrodecomp import RegistroDecomp
 from .dadosarquivo import DadosArquivoBlocos
 from .dadosarquivo import DadosArquivoRegistros
 from .dadosarquivo import DadosArquivoBinarios
@@ -86,6 +87,14 @@ class ArquivoRegistros:
     def _registros(self):
         return self._dados.registros
 
+    def cria_registro(self,
+                      anterior: RegistroDecomp,
+                      registro: RegistroDecomp) -> RegistroDecomp:
+        return self._dados.cria_registro(anterior, registro)
+
+    def deleta_registro(self, registro: RegistroDecomp) -> bool:
+        return self._dados.deleta_registro(registro)
+
     @classmethod
     @abstractmethod
     def le_arquivo(cls, diretorio: str, nome_arquivo="") -> 'ArquivoRegistros':
